# Cipher Module

Have you ever wanted to use ciphers in **python**?
If you have, you know that it's really hard to make functions for your cipher of choice,

**So that's why I made this module!**
You can use this module to simplify your ciphering process!
# Ciphers

This module, supports following ciphers (Note: other ciphers will be added to the module):
- Caeser
- Atbash
- Vigenere
- Base64
- A1Z26

# How to use

Every cipher, has a ``encode`` and ``decode`` function.

Most of them, take the argument `text` or `code`, but some of them, take more argument, like **Vigenere** which takes a `key` argument